.. :changelog:

History
-------

0.1.0 (2017-12-30)
++++++++++++++++++

* First release on PyPI.
* Initial models and REST API
* Syncs data from HGNC and UCSC to build database

0.2.0 (2018-01-5)
++++++++++++++++++

* Improved REST API Filters
* made Chromosomes and Gene Symbols save as uppercase to maintain consistency
